package com.ruoyi.web.controller.student;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.bean.BeanUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.StuClass;
import com.ruoyi.system.domain.StuRoom;
import com.ruoyi.system.domain.vo.FinanceExportVo;
import com.ruoyi.system.domain.vo.PaymentInfoVo;
import com.ruoyi.system.domain.vo.RegisterInfoVo;
import com.ruoyi.system.domain.vo.StudentManagerVo;
import com.ruoyi.system.service.IStuBaseInfoService;
import com.ruoyi.system.service.IStuClassService;
import com.ruoyi.system.service.IStuRoomService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;

/**
 * 学生管理 Controller
 *
 * @author liql
 * @date 2021-03-23
 */
@RestController
@RequestMapping("/student/base")
@Api(value = "学生信息管理",tags={"学生信息管理"})
public class StuBaseInfoController extends BaseController
{
    @Autowired
    private IStuBaseInfoService stuBaseInfoService;
    @Autowired
    private IStuRoomService stuRoomService;
    @Autowired
    private IStuClassService stuClassService;

    /**
     * 查询所有学生列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "所有学生列表")
    public TableDataInfo list(StuBaseInfo stuBaseInfo)
    {
        startPage();
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        return getDataTable(list);
    }

    /**
     * 查询所有学生列表
     */
    @GetMapping("/myClassStudentList")
    @ApiOperation(value = "我班学生列表")
    public TableDataInfo myClassStudentList(StuBaseInfo stuBaseInfo)
    {
        startPage();
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuBaseInfo.setUserId(userId);
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        return getDataTable(list);
    }


    /**
     * 查询未报到的学生
     */
    @GetMapping("/list0")
    @ApiOperation(value = "未报到的学生列表")
    public TableDataInfo list0(StuBaseInfo stuBaseInfo)
    {
        startPage();
        stuBaseInfo.setStudentStatus(0L);
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        return getDataTable(list);
    }

    /**
     * 查询已报到的学生
     */
    @GetMapping("/list1")
    @ApiOperation(value = "已报到的学生列表")
    public TableDataInfo list1(StuBaseInfo stuBaseInfo)
    {
        startPage();
        stuBaseInfo.setStudentStatus(1L);
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        return getDataTable(list);
    }

    /**
     * 查询已缴费的学生
     */
    @GetMapping("/list2")
    @ApiOperation(value = "已缴费的学生列表")
    public TableDataInfo list2(StuBaseInfo stuBaseInfo)
    {
        startPage();
        stuBaseInfo.setStudentStatus(2L);
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        return getDataTable(list);
    }

    /**
     * 查询已毕业的学生
     */
    @GetMapping("/list9")
    @ApiOperation(value = "已毕业的学生列表")
    public TableDataInfo list9(StuBaseInfo stuBaseInfo)
    {
        startPage();
        stuBaseInfo.setStudentStatus(9L);
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        return getDataTable(list);
    }

    /**
     * 查询待评分的学生
     */
    @GetMapping("/list99")
    @ApiOperation(value = "已毕业的学生列表")
    public TableDataInfo list99(StuBaseInfo stuBaseInfo)
    {
        startPage();
        stuBaseInfo.setStudentStatus(99L);
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        return getDataTable(list);
    }


    /**
     * 导出学生列表
     */
    @Log(title = "学生管理", businessType = BusinessType.EXPORT)
    @ApiOperation(value = "导出")
    @GetMapping("/export")
    public AjaxResult export(StuBaseInfo stuBaseInfo)
    {
        List<StuBaseInfo> list = stuBaseInfoService.selectStuBaseInfoList(stuBaseInfo);
        ExcelUtil<StuBaseInfo> util = new ExcelUtil<StuBaseInfo>(StuBaseInfo.class);
        return util.exportExcel(list, "base");
    }

    /**
     * 获取学生详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuBaseInfoService.selectStuBaseInfoById(id));
    }

    /**
     * 新增学生
     */
    @Log(title = "学生管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增学生信息")
    public AjaxResult add(@RequestBody StuBaseInfo stuBaseInfo)
    {
        return toAjax(stuBaseInfoService.insertStuBaseInfo(stuBaseInfo));
    }

    /**
     * 修改学生
     */
    @Log(title = "学生管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改学生信息")
    public AjaxResult edit(@RequestBody StuBaseInfo stuBaseInfo)
    {
        return toAjax(stuBaseInfoService.updateStuBaseInfo(stuBaseInfo));
    }

    /**
     * 新生缴费学生
     */
    @Log(title = "学生管理", businessType = BusinessType.UPDATE)
    @PutMapping("/new-payment")
    @ApiOperation(value = "新生缴费学生")
    public AjaxResult edit2(@RequestBody StuBaseInfo stuBaseInfo)
    {
        stuBaseInfo.setStudentStatus(1L);
        //stuBaseInfo.setPaymentDate(DateUtils.getNowDate());
        return toAjax(stuBaseInfoService.updateStuBaseInfo(stuBaseInfo));
    }

    /**
     * 老生缴费学生
     */
    @Log(title = "学生管理", businessType = BusinessType.UPDATE)
    @PutMapping("/old-payment")
    @ApiOperation(value = "老生缴费学生")
    public AjaxResult oldPayment(@RequestBody StuBaseInfo stuBaseInfo)
    {
        return toAjax(stuBaseInfoService.updateStuBaseInfo(stuBaseInfo));
    }


    /**
     * 删除学生
     */
    @Log(title = "学生管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除学生")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuBaseInfoService.deleteStuBaseInfoByIds(ids));
    }

    /**
     * 学生退学
     */
    @Log(title = "学生管理", businessType = BusinessType.UPDATE)
    @PutMapping("/exit/{ids}")
    @ApiOperation("学生退学")
    public AjaxResult exit(@PathVariable Long[] ids)
    {
        return toAjax(stuBaseInfoService.dropOutOfSchool(ids));
    }

    /**
     *  基础信息导入
     * @param file
     * @param updateSupport
     * @return
     * @throws Exception
     */
    @Log(title = "学生管理", businessType = BusinessType.IMPORT)
    @PostMapping("/importData")
    @ApiOperation(value = "导入学生信息")
    public AjaxResult importData(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<StuBaseInfo> util = new ExcelUtil<StuBaseInfo>(StuBaseInfo.class);
        List<StuBaseInfo> studentList = util.importExcel(file.getInputStream());
        String operName = SecurityUtils.getUsername();
        String message = stuBaseInfoService.importBaseInfo(studentList, updateSupport, operName);
        return AjaxResult.success(message);
    }

    @GetMapping("/importTemplate")
    @ApiOperation(value = "导入模板下载")
    public AjaxResult importTemplate(HttpServletResponse response) throws IOException {
        ExcelUtil<StuBaseInfo> util = new ExcelUtil<StuBaseInfo>(StuBaseInfo.class);
        return util.importTemplateExcel("学生基础信息导入模板");
    }

    /**
     * 报到登记信息导入
     * @param response
     * @return
     * @throws IOException
     */
    @GetMapping("/importRegisterTemplate")
    @ApiOperation(value = "报到登记信息导入模板下载")
    public AjaxResult importRegisterTemplate(HttpServletResponse response) throws IOException {
        ExcelUtil<RegisterInfoVo> util = new ExcelUtil<RegisterInfoVo>(RegisterInfoVo.class);
        return util.importTemplateExcel("报到登记信息模板");
    }

    @Log(title = "学生管理", businessType = BusinessType.IMPORT)
    @PostMapping("/importRegisterData")
    @ApiOperation(value = "报到登记信息导入")
    public AjaxResult importRegisterData(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<RegisterInfoVo> util = new ExcelUtil<RegisterInfoVo>(RegisterInfoVo.class);
        List<RegisterInfoVo> studentRegisterList = util.importExcel(file.getInputStream());
        List<StuBaseInfo> studentList = new ArrayList<>();
        for(RegisterInfoVo vo:studentRegisterList){
            StuBaseInfo stu = new StuBaseInfo();
            BeanUtils.copyBeanProp(stu,vo);
            stu.setStudentStatus(1L);
            studentList.add(stu);
        }
        String operName = SecurityUtils.getUsername();
        String message = stuBaseInfoService.importBaseInfo(studentList, updateSupport, operName);
        return AjaxResult.success(message);
    }

    /**
     * 缴费信息导入
     * @param response
     * @return
     * @throws IOException
     */
    @GetMapping("/importPaymentTemplate")
    @ApiOperation(value = "缴费信息导入模板下载")
    public AjaxResult importPaymentTemplate(HttpServletResponse response) throws IOException {
        ExcelUtil<PaymentInfoVo> util = new ExcelUtil<PaymentInfoVo>(PaymentInfoVo.class);
        return util.importTemplateExcel("学生缴费信息模板");
    }

    @Log(title = "学生管理", businessType = BusinessType.IMPORT)
    @PostMapping("/importPaymentData")
    @ApiOperation(value = "缴费信息导入")
    public AjaxResult importPaymentData(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<PaymentInfoVo> util = new ExcelUtil<PaymentInfoVo>(PaymentInfoVo.class);
        List<PaymentInfoVo> studentPaymentList = util.importExcel(file.getInputStream());
        List<StuBaseInfo> studentList = new ArrayList<>();
        for(PaymentInfoVo vo:studentPaymentList){
            StuBaseInfo stu = new StuBaseInfo();
            stu.setStudentStatus(2L);
            BeanUtils.copyBeanProp(stu,vo);
            studentList.add(stu);
        }
        String operName = SecurityUtils.getUsername();
        String message = stuBaseInfoService.importBaseInfo(studentList, updateSupport, operName);
        return AjaxResult.success(message);
    }

    /**
     * 学生管理信息导入
     * @param response
     * @return
     * @throws IOException
     */
    @GetMapping("/importManagerTemplate")
    @ApiOperation(value = "学生管理信息导入模板下载")
    public AjaxResult importStudentManagerTemplate(HttpServletResponse response) throws IOException {
        ExcelUtil<StudentManagerVo> util = new ExcelUtil<StudentManagerVo>(StudentManagerVo.class);
        return util.importTemplateExcel("学生管理信息模板");
    }

    @Log(title = "学生管理", businessType = BusinessType.IMPORT)
    @PostMapping("/importManagerData")
    @ApiOperation(value = "学生管理信息导入")
    public AjaxResult importManagerData(MultipartFile file, boolean updateSupport) throws Exception {
        ExcelUtil<StudentManagerVo> util = new ExcelUtil<StudentManagerVo>(StudentManagerVo.class);
        List<StudentManagerVo> studentManagerList = util.importExcel(file.getInputStream());
        List<StuBaseInfo> studentList = new ArrayList<>();
        for(StudentManagerVo vo:studentManagerList){
            StuBaseInfo stu = new StuBaseInfo();
            StuClass stuClass = stuClassService.queryClassByName(vo.getClassName());
            vo.setClassId(stuClass.getId());
            StuRoom room = stuRoomService.queryRoomByName(vo.getRoomName());
            vo.setRoomId(room.getId());

            BeanUtils.copyBeanProp(stu,vo);
            stu.setBuildingId(room.getBuiddingId());
            studentList.add(stu);
        }
        String operName = SecurityUtils.getUsername();
        String message = stuBaseInfoService.importBaseInfo(studentList, updateSupport, operName);
        return AjaxResult.success(message);
    }


    /**
     * 财务导出学生信息列表
     */
    @Log(title = "学生管理", businessType = BusinessType.EXPORT)
    @ApiOperation(value = "学生财务数据导出")
    @GetMapping("/financeExport")
    public AjaxResult finaceExport(StuBaseInfo stuBaseInfo)
    {
        List<FinanceExportVo> list = stuBaseInfoService.selectStuFinanceInfoList(stuBaseInfo);
        ExcelUtil<FinanceExportVo> util = new ExcelUtil<FinanceExportVo>(FinanceExportVo.class);
        return util.exportExcel(list, "学生财务数据");
    }

    /**
     * 根据寝室id获取学生列表
     */
    @GetMapping(value = "/query-list/{roomId}")
    @ApiOperation("根据寝室id获取学生列表")
    public AjaxResult getList(@PathVariable("roomId") Long roomId)
    {
        return AjaxResult.success(stuBaseInfoService.selectStudentByRoomId(roomId));
    }


}
