package com.ruoyi.web.controller.student;

import java.util.List;

import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.StuTextBook;
import com.ruoyi.system.domain.param.ApplyListParam;
import com.ruoyi.system.domain.vo.ApplyListVo;
import com.ruoyi.system.service.IStuBaseInfoService;
import com.ruoyi.system.service.IStuTextBookService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuBookApply;
import com.ruoyi.system.service.IStuBookApplyService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 教材申请Controller
 * 
 * @author liql
 * @date 2021-09-27
 */
@RestController
@RequestMapping("/apply/book")
@Api(tags = {"教材申请管理接口"})
public class StuBookApplyController extends BaseController
{
    @Autowired
    private IStuBookApplyService stuBookApplyService;

    @Autowired
    private IStuBaseInfoService stuBaseInfoService;


    /**
     * 查询教材申请列表
     */
    @GetMapping("/list")
    @ApiOperation("教材申请审批列表接口")
    public TableDataInfo list(ApplyListParam param)
    {
        startPage();
        List<ApplyListVo> list = stuBookApplyService.selectStuBookApplyList(param);
        return getDataTable(list);
    }

    /**
     * 我的教材申请列表
     */
    @GetMapping("/myList")
    @ApiOperation("我的教材申请列表接口")
    public TableDataInfo myList(ApplyListParam param)
    {
        startPage();
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        param.setCreateBy(userId);

        List<ApplyListVo> list = stuBookApplyService.selectStuBookApplyList(param);
        return getDataTable(list);
    }

    /**
     * 获取教材申请详细信息
     */
   @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuBookApplyService.selectStuBookApplyById(id));
    }

    /**
     * 新增教材申请
     */
    @Log(title = "教材申请", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增发放教材申请")
    public AjaxResult add(@RequestBody StuBookApply stuBookApply)
    {
        return toAjax(stuBookApplyService.insertStuBookApply(stuBookApply));
    }

    /**
     * 修改教材申请
     */
    @Log(title = "教材申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuBookApply stuBookApply)
    {
        return toAjax(stuBookApplyService.updateStuBookApply(stuBookApply));
    }

    /**
     * 删除教材申请
     */
    @Log(title = "教材申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation(value = "删除")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuBookApplyService.deleteStuBookApplyByIds(ids));
    }

    /**
     * 发放教材审核
     */
    @Log(title = "教材申请", businessType = BusinessType.UPDATE)
    @PutMapping("/approval")
    @ApiOperation(value = "审批")
    public AjaxResult approval(@RequestBody StuBookApply stuBookApply)
    {
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuBookApply.setUpdateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(stuBookApply.getStudentId());
        student.setBookApplyStatus(2);
        stuBaseInfoService.updateStuBaseInfo(student);

        return toAjax(stuBookApplyService.updateStuBookApply(stuBookApply));
    }

    /**
     * 教材发放
     */
    @Log(title = "教材申请", businessType = BusinessType.UPDATE)
    @PutMapping("/grant")
    @ApiOperation(value = "发放")
    public AjaxResult grant(@RequestBody StuBookApply stuBookApply)
    {
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuBookApply.setUpdateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(stuBookApply.getStudentId());
        student.setBookApplyStatus(3);
        stuBaseInfoService.updateStuBaseInfo(student);

        return toAjax(stuBookApplyService.updateStuBookApply(stuBookApply));
    }

}
