package com.ruoyi.web.controller.student;

import java.util.List;

import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuBuilding;
import com.ruoyi.system.service.IStuBuildingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 楼宇Controller
 * 
 * @author liql
 * @date 2021-06-17
 */
@RestController
@RequestMapping("/dorm/building")
public class StuBuildingController extends BaseController
{
    @Autowired
    private IStuBuildingService stuBuildingService;

    /**
     * 查询楼宇列表
     */
    @GetMapping("/list")
    public TableDataInfo list(StuBuilding stuBuilding)
    {
        startPage();
        List<StuBuilding> list = stuBuildingService.selectStuBuildingList(stuBuilding);
        return getDataTable(list);
    }

    /**
     * 导出楼宇列表
     */
    @PreAuthorize("@ss.hasPermi('dorm:building:export')")
    @Log(title = "楼宇", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StuBuilding stuBuilding)
    {
        List<StuBuilding> list = stuBuildingService.selectStuBuildingList(stuBuilding);
        ExcelUtil<StuBuilding> util = new ExcelUtil<StuBuilding>(StuBuilding.class);
        return util.exportExcel(list, "building");
    }

    /**
     * 获取楼宇详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuBuildingService.selectStuBuildingById(id));
    }

    /**
     * 新增楼宇
     */
    @Log(title = "楼宇", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StuBuilding stuBuilding)
    {
        return toAjax(stuBuildingService.insertStuBuilding(stuBuilding));
    }

    /**
     * 修改楼宇
     */
    @Log(title = "楼宇", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuBuilding stuBuilding)
    {
        return toAjax(stuBuildingService.updateStuBuilding(stuBuilding));
    }

    /**
     * 删除楼宇
     */
    @Log(title = "楼宇", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuBuildingService.deleteStuBuildingByIds(ids));
    }

}
