package com.ruoyi.web.controller.student;

import java.util.List;

import com.ruoyi.system.domain.param.ClassBookConfigParam;
import com.ruoyi.system.domain.vo.BookConfigVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.ibatis.annotations.Param;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuClassBookConfig;
import com.ruoyi.system.service.IStuClassBookConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 教材配置Controller
 * 
 * @author liql
 * @date 2021-09-27
 */
@RestController
@RequestMapping("/book/config")
@Api(tags = {"班级配置教材管理接口"})
public class StuClassBookConfigController extends BaseController
{
    @Autowired
    private IStuClassBookConfigService stuClassBookConfigService;

    /**
     * 查询教材配置列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "根据班级id获取教材配置列表接口")
    public AjaxResult list(Long classId)
    {
        List<BookConfigVo> list = stuClassBookConfigService.selectClassBookConfigListByClassId(classId);
        return AjaxResult.success(list);
    }


    /**
     * 获取教材配置详细信息
     */
    @GetMapping(value = "/{classId}")
    public AjaxResult getInfo(@PathVariable("classId") Long classId)
    {
        return AjaxResult.success(stuClassBookConfigService.selectStuClassBookConfigById(classId));
    }

    /**
     * 新增教材配置
     */
    @Log(title = "教材配置", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "添加班级教材配置")
    public AjaxResult add(@RequestBody StuClassBookConfig stuClassBookConfig)
    {
        return toAjax(stuClassBookConfigService.insertStuClassBookConfig(stuClassBookConfig));
    }

    /**
     * 修改教材配置
     */
    @Log(title = "教材配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuClassBookConfig stuClassBookConfig)
    {
        return toAjax(stuClassBookConfigService.updateStuClassBookConfig(stuClassBookConfig));
    }

    /**
     * 删除教材配置
     */
    @Log(title = "教材配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/batchRemove")
    @ApiOperation(value = "批量删除班级教材配置")
    public AjaxResult remove(@RequestBody ClassBookConfigParam[] params)
    {
        return toAjax(stuClassBookConfigService.deleteStuClassBookConfigByParams(params));
    }


    /**
     * 删除教材配置
     */
    @Log(title = "教材配置", businessType = BusinessType.DELETE)
    @DeleteMapping("/singleRemove")
    @ApiOperation(value = "单个删除班级教材配置")
    public AjaxResult singleRemove(@RequestBody ClassBookConfigParam param)
    {
        return toAjax(stuClassBookConfigService.deleteStuClassBookConfigByParam(param));
    }
}
