package com.ruoyi.web.controller.student;

import java.util.List;

import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuCollege;
import com.ruoyi.system.service.IStuCollegeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学院Controller
 *
 * @author liql
 * @date 2021-03-23
 */
@RestController
@RequestMapping("/department/college")
@Api(value = "学院管理",tags={"学院管理"})
public class StuCollegeController extends BaseController
{
    @Autowired
    private IStuCollegeService stuCollegeService;

    /**
     * 查询学院列表
     */
    @GetMapping("/list")
    public TableDataInfo list(StuCollege stuCollege)
    {
        startPage();
        List<StuCollege> list = stuCollegeService.selectStuCollegeList(stuCollege);
        return getDataTable(list);
    }

    /**
     * 导出学院列表
     */
    @Log(title = "学院", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StuCollege stuCollege)
    {
        List<StuCollege> list = stuCollegeService.selectStuCollegeList(stuCollege);
        ExcelUtil<StuCollege> util = new ExcelUtil<StuCollege>(StuCollege.class);
        return util.exportExcel(list, "college");
    }

    /**
     * 获取学院详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuCollegeService.selectStuCollegeById(id));
    }

    /**
     * 新增学院
     */
    @Log(title = "学院", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StuCollege stuCollege)
    {
        return toAjax(stuCollegeService.insertStuCollege(stuCollege));
    }

    /**
     * 修改学院
     */
    @Log(title = "学院", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuCollege stuCollege)
    {
        return toAjax(stuCollegeService.updateStuCollege(stuCollege));
    }

    /**
     * 删除学院
     */
    @Log(title = "学院", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuCollegeService.deleteStuCollegeByIds(ids));
    }
}
