package com.ruoyi.web.controller.student;

import java.util.List;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuDepartment;
import com.ruoyi.system.service.IStuDepartmentService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 科系Controller
 *
 * @author liql
 * @date 2021-03-23
 */
@RestController
@RequestMapping("/department/depart")
@Api(value = "科系管理",tags={"科系管理"})
public class StuDepartmentController extends BaseController
{
    @Autowired
    private IStuDepartmentService stuDepartmentService;

    /**
     * 查询科系列表
     */
    @GetMapping("/list")
    @ApiOperation("科系列表")
    public TableDataInfo list(StuDepartment stuDepartment)
    {
        startPage();
        List<StuDepartment> list = stuDepartmentService.selectStuDepartmentList(stuDepartment);
        return getDataTable(list);
    }

    /**
     * 导出科系列表
     */
    @Log(title = "科系", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StuDepartment stuDepartment)
    {
        List<StuDepartment> list = stuDepartmentService.selectStuDepartmentList(stuDepartment);
        ExcelUtil<StuDepartment> util = new ExcelUtil<StuDepartment>(StuDepartment.class);
        return util.exportExcel(list, "depart");
    }

    /**
     * 获取科系详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuDepartmentService.selectStuDepartmentById(id));
    }

    /**
     * 新增科系
     */
    @Log(title = "科系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StuDepartment stuDepartment)
    {
        return toAjax(stuDepartmentService.insertStuDepartment(stuDepartment));
    }

    /**
     * 修改科系
     */
    @Log(title = "科系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuDepartment stuDepartment)
    {
        return toAjax(stuDepartmentService.updateStuDepartment(stuDepartment));
    }

    /**
     * 删除科系
     */
    @Log(title = "科系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuDepartmentService.deleteStuDepartmentByIds(ids));
    }

    /**
     * 获取科系详细信息
     */
    @GetMapping(value = "/query-list/{collegeId}")
    @ApiOperation("根据学院id获取专业列表")
    public TableDataInfo getList(@PathVariable("collegeId") Long collegeId)
    {
        return getDataTable(stuDepartmentService.queryList(collegeId));
    }
}
