package com.ruoyi.web.controller.student;

import java.util.List;

import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.param.ApplyListParam;
import com.ruoyi.system.domain.vo.ApplyListVo;
import com.ruoyi.system.service.IStuBaseInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuOutSchoolApply;
import com.ruoyi.system.service.IStuOutSchoolApplyService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 失学申请Controller
 * 
 * @author liql
 * @date 2021-09-27
 */
@RestController
@RequestMapping("/apply/out")
@Api(tags = {"失学申请管理接口"})
public class StuOutSchoolApplyController extends BaseController
{
    @Autowired
    private IStuOutSchoolApplyService stuOutSchoolApplyService;
    @Autowired
    private IStuBaseInfoService stuBaseInfoService;

    /**
     * 查询失学申请列表
     */
    @GetMapping("/list")
    @ApiOperation("失学申请审批列表接口")
    public TableDataInfo list(ApplyListParam param)
    {
        startPage();
        List<ApplyListVo> list = stuOutSchoolApplyService.selectStuOutSchoolApplyList(param);
        return getDataTable(list);
    }

    /**
     * 我的失学申请列表
     */
    @GetMapping("/myList")
    @ApiOperation("我的失学申请列表接口")
    public TableDataInfo myList(ApplyListParam param)
    {
        startPage();
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        param.setCreateBy(userId);
        List<ApplyListVo> list = stuOutSchoolApplyService.selectStuOutSchoolApplyList(param);
        return getDataTable(list);
    }


    /**
     * 获取失学申请详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuOutSchoolApplyService.selectStuOutSchoolApplyById(id));
    }

    /**
     * 新增失学申请
     */
    @Log(title = "失学申请", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增失学申请接口")
    public AjaxResult add(@RequestBody StuOutSchoolApply stuOutSchoolApply)
    {
        return toAjax(stuOutSchoolApplyService.insertStuOutSchoolApply(stuOutSchoolApply));
    }

    /**
     * 修改失学申请
     */
    @Log(title = "失学申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuOutSchoolApply stuOutSchoolApply)
    {
        return toAjax(stuOutSchoolApplyService.updateStuOutSchoolApply(stuOutSchoolApply));
    }

    /**
     * 删除失学申请
     */
    @Log(title = "失学申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuOutSchoolApplyService.deleteStuOutSchoolApplyByIds(ids));
    }


    /**
     * 失学审批
     */
    @Log(title = "失学申请", businessType = BusinessType.UPDATE)
    @PutMapping("/approval")
    @ApiOperation(value = "失学审批")
    public AjaxResult approval(@RequestBody StuOutSchoolApply outSchoolApply)
    {
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        outSchoolApply.setUpdateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(outSchoolApply.getStudentId());
        student.setOutApplyStatus(2);
        stuBaseInfoService.updateStuBaseInfo(student);

        return toAjax(stuOutSchoolApplyService.updateStuOutSchoolApply(outSchoolApply));
    }

    /**
     * 发放教材
     */
    @Log(title = "失学申请", businessType = BusinessType.UPDATE)
    @PutMapping("/finish")
    @ApiOperation(value = "完成失学")
    public AjaxResult finish(@RequestBody StuOutSchoolApply outSchoolApply)
    {
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        outSchoolApply.setUpdateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(outSchoolApply.getStudentId());
        student.setOutApplyStatus(3);
        stuBaseInfoService.updateStuBaseInfo(student);

        return toAjax(stuOutSchoolApplyService.updateStuOutSchoolApply(outSchoolApply));
    }
}
