package com.ruoyi.web.controller.student;

import java.util.List;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuProfession;
import com.ruoyi.system.service.IStuProfessionService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 专业Controller
 *
 * @author liql
 * @date 2021-03-23
 */
@RestController
@RequestMapping("/department/profession")
@Api(value = "专业管理",tags={"专业管理"})
public class StuProfessionController extends BaseController
{
    @Autowired
    private IStuProfessionService stuProfessionService;

    /**
     * 查询专业列表
     */
    @GetMapping("/list")
    @ApiOperation("专业列表")
    public TableDataInfo list(StuProfession stuProfession)
    {
        startPage();
        List<StuProfession> list = stuProfessionService.selectStuProfessionList(stuProfession);
        return getDataTable(list);
    }

    /**
     * 导出专业列表
     */
    @Log(title = "专业", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(StuProfession stuProfession)
    {
        List<StuProfession> list = stuProfessionService.selectStuProfessionList(stuProfession);
        ExcelUtil<StuProfession> util = new ExcelUtil<StuProfession>(StuProfession.class);
        return util.exportExcel(list, "profession");
    }

    /**
     * 获取专业详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuProfessionService.selectStuProfessionById(id));
    }

    /**
     * 新增专业
     */
    @Log(title = "专业", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StuProfession stuProfession)
    {
        return toAjax(stuProfessionService.insertStuProfession(stuProfession));
    }

    /**
     * 修改专业
     */
    @Log(title = "专业", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuProfession stuProfession)
    {
        return toAjax(stuProfessionService.updateStuProfession(stuProfession));
    }

    /**
     * 删除专业
     */
    @Log(title = "专业", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuProfessionService.deleteStuProfessionByIds(ids));
    }

    /**
     * 获取专业列表
     */
    @GetMapping(value = "/query-list")
    @ApiOperation("根据科系id获取专业列表")
    public TableDataInfo getList()
    {
        return getDataTable(stuProfessionService.queryList());
    }
}
