package com.ruoyi.web.controller.student;

import java.util.List;

import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.param.ApplyListParam;
import com.ruoyi.system.domain.vo.ApplyListVo;
import com.ruoyi.system.service.IStuBaseInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuQuitSchoolApply;
import com.ruoyi.system.service.IStuQuitSchoolApplyService;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 退学申请Controller
 * 
 * @author liql
 * @date 2021-09-27
 */
@RestController
@RequestMapping("/apply/quit")
@Api(tags = {"退学申请管理接口"})
public class StuQuitSchoolApplyController extends BaseController
{
    @Autowired
    private IStuQuitSchoolApplyService stuQuitSchoolApplyService;
    @Autowired
    private IStuBaseInfoService stuBaseInfoService;

    /**
     * 查询退学申请列表
     */
    @GetMapping("/list")
    @ApiOperation("退学申请审批列表接口")
    public TableDataInfo list(ApplyListParam param)
    {
        startPage();
        List<ApplyListVo> list = stuQuitSchoolApplyService.selectStuQuitSchoolApplyList(param);
        return getDataTable(list);
    }

    /**
     * 查询退学申请列表
     */
    @GetMapping("/myList")
    @ApiOperation("我的退学申请列表接口")
    public TableDataInfo myList(ApplyListParam param)
    {
        startPage();
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        param.setCreateBy(userId);

        List<ApplyListVo> list = stuQuitSchoolApplyService.selectStuQuitSchoolApplyList(param);
        return getDataTable(list);
    }

    /**
     * 获取退学申请详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(stuQuitSchoolApplyService.selectStuQuitSchoolApplyById(id));
    }

    /**
     * 新增退学申请
     */
    @Log(title = "退学申请", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增退学申请接口")
    public AjaxResult add(@RequestBody StuQuitSchoolApply stuQuitSchoolApply)
    {
        return toAjax(stuQuitSchoolApplyService.insertStuQuitSchoolApply(stuQuitSchoolApply));
    }

    /**
     * 修改退学申请
     */
    @Log(title = "退学申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StuQuitSchoolApply stuQuitSchoolApply)
    {
        return toAjax(stuQuitSchoolApplyService.updateStuQuitSchoolApply(stuQuitSchoolApply));
    }

    /**
     * 删除退学申请
     */
    @Log(title = "退学申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(stuQuitSchoolApplyService.deleteStuQuitSchoolApplyByIds(ids));
    }

    /**
     * 退学审批
     */
    @Log(title = "退学申请", businessType = BusinessType.UPDATE)
    @PutMapping("/approval")
    @ApiOperation(value = "退学审批")
    public AjaxResult approval(@RequestBody StuQuitSchoolApply quitSchoolApply)
    {
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        quitSchoolApply.setUpdateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(quitSchoolApply.getStudentId());
        student.setQuitApplyStatus(2);
        stuBaseInfoService.updateStuBaseInfo(student);

        return toAjax(stuQuitSchoolApplyService.updateStuQuitSchoolApply(quitSchoolApply));
    }

    /**
     * 完成退学
     */
    @Log(title = "退学申请", businessType = BusinessType.UPDATE)
    @PutMapping("/finish")
    @ApiOperation(value = "完成退学")
    public AjaxResult finish(@RequestBody StuQuitSchoolApply quitSchoolApply)
    {
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        quitSchoolApply.setUpdateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(quitSchoolApply.getStudentId());
        student.setQuitApplyStatus(3);
        stuBaseInfoService.updateStuBaseInfo(student);

        return toAjax(stuQuitSchoolApplyService.updateStuQuitSchoolApply(quitSchoolApply));
    }

}
