package com.ruoyi.web.controller.student;

import java.util.List;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StuTextBook;
import com.ruoyi.system.service.IStuTextBookService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 教材Controller
 * 
 * @author liql
 * @date 2021-09-27
 */
@RestController
@RequestMapping("/system/book")
@Api(tags = {"教材管理接口"})
public class StuTextBookController extends BaseController
{
    @Autowired
    private IStuTextBookService stuTextBookService;

    /**
     * 查询教材列表
     */
    @GetMapping("/list")
    @ApiOperation(value = "列表")
    public TableDataInfo list(StuTextBook stuTextBook)
    {
        startPage();
        List<StuTextBook> list = stuTextBookService.selectStuTextBookList(stuTextBook);
        return getDataTable(list);
    }

    /**
     * 导出教材列表
     */
    @Log(title = "教材", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    @ApiOperation(value = "导出")
    public AjaxResult export(StuTextBook stuTextBook)
    {
        List<StuTextBook> list = stuTextBookService.selectStuTextBookList(stuTextBook);
        ExcelUtil<StuTextBook> util = new ExcelUtil<StuTextBook>(StuTextBook.class);
        return util.exportExcel(list, "book");
    }

    /**
     * 获取教材详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "详情")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return AjaxResult.success(stuTextBookService.selectStuTextBookById(id));
    }

    /**
     * 新增教材
     */
    @Log(title = "教材", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增")
    public AjaxResult add(@RequestBody StuTextBook stuTextBook)
    {
        return toAjax(stuTextBookService.insertStuTextBook(stuTextBook));
    }

    /**
     * 修改教材
     */
    @Log(title = "教材", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改")
    public AjaxResult edit(@RequestBody StuTextBook stuTextBook)
    {
        return toAjax(stuTextBookService.updateStuTextBook(stuTextBook));
    }

    /**
     * 删除教材
     */
    @Log(title = "教材", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation(value = "删除")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(stuTextBookService.deleteStuTextBookByIds(ids));
    }


    /**
     * 删除教材
     */
    @GetMapping("/bookList")
    @ApiOperation(value = "教材配置列表")
    public AjaxResult bookList()
    {
        return AjaxResult.success(stuTextBookService.selectClassBookList());
    }
}
