package com.ruoyi.system.domain;

import java.math.BigDecimal;
import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;

/**
 * 学生对象 stu_base_info
 *
 * @author liql
 * @date 2021-03-23
 */
@ApiModel("学生信息模型")
public class StuBaseInfo extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键id */
    @ApiModelProperty(value = "主键id")
    private Long id;

    /** 姓名 */
    @Excel(name = "姓名")
    @ApiModelProperty(value = "学生姓名")
    private String studentName;

    /** 性别 */
    @Excel(name = "性别",readConverterExp = "0=男,1=女,2=未知",combo = {"男","女","未知"})
    @ApiModelProperty(value = "性别")
    private String sex;

    /** 学历 */
    @Excel(name = "学历")
    @ApiModelProperty(value = "学历")
    private String educationBackground;

    /** 应届生、往届生 */
    @Excel(name = "应届生、往届生",combo={"应届生","往届生"})
    @ApiModelProperty(value = "应届生、往届生")
    private String freshStudent;

    /** 身份证号码 */
    @Excel(name = "身份证号码")
    @ApiModelProperty(value = "身份证号码")
    @NotNull
    @NotEmpty
    private String idCardNumber;

    //@Excel(name = "学号")
    @ApiModelProperty(value = "学号")
    private String studentNumber;

    /** 学生状态（0未报到，1已报到,2已缴费，3第二次缴费，4第三次缴费，5第四次缴费 6第五次缴费，7第六次缴费，8已评分，9已毕业，10已就业） */
    //@Excel(name = "学生状态")
    @ApiModelProperty(value = "学生状态（0未报到，1已报到,2已缴费，3第二次缴费，4第三次缴费，5第四次缴费 6第五次缴费，7第六次缴费，8已评分")
    private Long studentStatus;

    /** 联系电话 */
    @Excel(name = "联系电话")
    @ApiModelProperty(value = "联系电话")
    private String phone;

    @JsonFormat(pattern = "yyyy-MM-dd")
    @Excel(name = "应报到日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(value = "应报到日期")
    private Date shouldRegisterDate;

    /** 生源地 */
    @Excel(name = "生源地")
    @ApiModelProperty(value = "生源地")
    private String originOfStudent;

    /** 毕业学校 */
    @Excel(name = "毕业学校")
    @ApiModelProperty(value = "毕业学校")
    private String graduatedFrom;

    /** 专业id */
    //@Excel(name = "专业id")
    @ApiModelProperty(value = "专业id")
    private Long professionId;

    /** 报读专业 */
    @Excel(name = "报读专业")
    @ApiModelProperty(value = "报读专业")
    private String professionName;

    /** 年级id */
    //@Excel(name = "年级id")
    @ApiModelProperty(value = "年级id")
    private Long classId;

    /** 年级名称 */
    //@Excel(name = "年级名称")
    @ApiModelProperty(value = "年级名称")
    private String className;

    /** 保险购买状态 */
    //@Excel(name = "保险购买状态")
    @ApiModelProperty(value = "保险购买状态")
    private Long insuranceIsBuy;

    /** 寝室id */
    //@Excel(name = "寝室id")
    @ApiModelProperty(value = "寝室id")
    private Long roomId;

    @Excel(name = "寝室名")
    @ApiModelProperty(value = "寝室名")
    private String roomName;

    /** 楼宇id */
    //@Excel(name = "楼宇id")
    @ApiModelProperty(value = "楼宇id")
    private Long buildingId;

    /** 楼宇id */
    @Excel(name = "楼宇名")
    @ApiModelProperty(value = "楼宇名")
    private String buildingName;

    /** 校服分发状态 */
    //@Excel(name = "校服分发状态")
    @ApiModelProperty(value = "校服分发状态")
    private Long uniformIsHandOut;

    /** 课本分发状态 */
    //@Excel(name = "课本分发状态")
    @ApiModelProperty(value = "课本分发状态")
    private Long textbookIsHandOut;

    /** 裤子发放状态 **/
    private Integer quiltIsHandOut;

    /** 综合评分 */
    //@Excel(name = "综合评分")
    @ApiModelProperty(value = "综合评分")
    private Long score;

    /** 评分依据 */
    //@Excel(name = "评分依据")
    @ApiModelProperty(value = "评分依据")
    private String scoreBy;

    /** 入职公司名称 */
    //@Excel(name = "入职公司名称")
    @ApiModelProperty(value = "入职公司名称")
    private String companyName;

    /** 入职日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    //@Excel(name = "入职日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(value = "入职日期")
    private Date entryDate;

    /** 公司地址 */
    //@Excel(name = "公司地址")
    @ApiModelProperty(value = "公司地址")
    private String companyAddress;

    /** $column.columnComment */
    //@Excel(name = "公司联系人")
    @ApiModelProperty(value = "公司联系人")
    private String contactName;

    /** 公司联系电话 */
    //@Excel(name = "公司联系电话")
    @ApiModelProperty(value = "公司联系电话")
    private String companyPhone;

    /** 是否建档立卡贫困户 */
    //@Excel(name = "是否建档立卡贫困户")
    @ApiModelProperty(value = "是否建档立卡贫困户0否，1是")
    private Long poorHouseholdsIs;

    /** 实际报到日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    //@Excel(name = "实际报到日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(value = "实际报到日期")
    private Date registerDate;

    /** 正式入学日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    //@Excel(name = "正式入学日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(value = "正式入学日期")
    private Date enrollmentDate;

    /** 应收住宿费 */
    //@Excel(name = "应收杂费")
    @ApiModelProperty(value = "校服费")
    private BigDecimal receivableIncidentals;

    /** 床上用品费用 **/
    @ApiModelProperty(value = "床上用品费用")
    private BigDecimal beddingFee;

    /** 应收住宿费 */
    //@Excel(name = "应收住宿费")
    @ApiModelProperty(value = "应收住宿费")
    private BigDecimal receivableQuarterage;

    @ApiModelProperty(value = "应收费总计")
    private BigDecimal receivableTotal;

    /** 实收住宿费 */
    //@Excel(name = "实收杂费")
    @ApiModelProperty(value = "实收杂费")
    private BigDecimal officialIncidentals;

    /** 杂费票据号 */
    //@Excel(name = "杂费票据号")
    @ApiModelProperty(value = "杂费票据号")
    private String incidentalsBillNo;

    /** 实收住宿费 */
    //@Excel(name = "实收住宿费")
    @ApiModelProperty(value = "实收住宿费")
    private BigDecimal officialQuarterage;

    @ApiModelProperty(value = "实收费总计")
    private BigDecimal officialTotal;

    /** 住宿费票据号 */
    //@Excel(name = "住宿费票据号")
    @ApiModelProperty(value = "住宿费票据号")
    private String quarterageBillNo;

    /** 登记收费人员 */
    //@Excel(name = "登记收费人员")
    @ApiModelProperty(value = "登记收费人员")
    private String chargerName;

    /** 缴费日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    //@Excel(name = "缴费日期", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(value = "缴费日期")
    private Date paymentDate;

    //@Excel(name = "缴费方式",dictType="stu_payment_method",combo={"微信","支付宝","现金","银行转账","信用卡","支票","其它"},readConverterExp="0=微信,1=支付宝,2=现金,3=银行转账,4=信用卡,5=支票,6=其它")
    @ApiModelProperty(value = "缴费方式")
    private String paymentMethod;

    /** 开票员 */
   // @Excel(name = "开票员")
    @ApiModelProperty(value = "开票员")
    private String drawer;

    /** 联系老师 */
    //@Excel(name = "联系老师")
    @ApiModelProperty(value = "联系老师")
    private String contactTeacher;

    /** 杂费票据序号 */
    //@Excel(name = "杂费票据序号")
    @ApiModelProperty(value = "杂费票据序号")
    private String incidentalsBillSerial;

    /** 第一学年下半年是否缴费 */
    //@Excel(name = "第一学年下半年是否缴费")
    @ApiModelProperty(value = "第一学年下半年是否缴费0未缴 1已缴")
    private Long firstLowHalfIs;

    @ApiModelProperty(value = "第一学年下半年学费")
    private BigDecimal firstLowFees;

    /** 第二学年上半年是否缴费 */
    //@Excel(name = "第二学年上半年是否缴费")
    @ApiModelProperty(value = "第二学年上半年是否缴费0未缴 1已缴")
    private Long secondUpHalfIs;

    @ApiModelProperty(value = "第二学年上半年学费")
    private BigDecimal secondUpFees;


    /** 第二学年下半年是否缴费 */
    //@Excel(name = "第二学年下半年是否缴费")
    @ApiModelProperty(value = "第二学年下半年是否缴费0未缴 1已缴")
    private Long secondLowHalfIs;

    @ApiModelProperty(value = "第二学年下半年学费")
    private BigDecimal secondLowFees;


    /** 第三学年上半年是否缴费 */
    //@Excel(name = "第三学年上半年是否缴费")
    @ApiModelProperty(value = "第三学年上半年是否缴费0未缴 1已缴")
    private Long thirdUpHalfIs;

    @ApiModelProperty(value = "第三学年上半年学费")
    private BigDecimal thirdUpFees;

    /** 第三学年下半年是否缴费 */
    //@Excel(name = "第三学年下半年是否缴费")
    @ApiModelProperty(value = "第三学年下半年是否缴费0未缴 1已缴")
    private Long thirdLowHalfIs;

    @ApiModelProperty(value = "第三学年下半年是学费")
    private BigDecimal thirdLowFees;

    /** 缴费次数 */
    //@Excel(name = "缴费次数")
    @ApiModelProperty(value = "缴费次数")
    private Long chargeTimes;

    private Long departmentId;
    private String departmentName;
    private Long collegeId;
    private String collegeName;
    private Long userId;
    private Integer quitApplyStatus;
    private Integer outApplyStatus;
    private Integer bookApplyStatus;
    /** 删除标志（0代表存在 1代表删除） */
    private String delFlag;
    private Integer roomType;

    @Excel(name = "票据代码")
    private String billCode;
    @Excel(name = "项目编码")
    private String projectCode;
    @Excel(name = "开票日期")
    private Date ticketDate;

    public Long getBuildingId() {
        return buildingId;
    }

    public void setBuildingId(Long buildingId) {
        this.buildingId = buildingId;
    }

    public void setId(Long id)
    {
        this.id = id;
    }

    public Long getId()
    {
        return id;
    }
    public void setStudentName(String studentName)
    {
        this.studentName = studentName;
    }

    public String getStudentName()
    {
        return studentName;
    }
    public void setSex(String sex)
    {
        this.sex = sex;
    }

    public String getSex()
    {
        return sex;
    }
    public void setEducationBackground(String educationBackground)
    {
        this.educationBackground = educationBackground;
    }

    public String getEducationBackground()
    {
        return educationBackground;
    }
    public void setFreshStudent(String freshStudent)
    {
        this.freshStudent = freshStudent;
    }

    public String getFreshStudent()
    {
        return freshStudent;
    }
    public void setIdCardNumber(String idCardNumber)
    {
        this.idCardNumber = idCardNumber;
    }

    public String getIdCardNumber()
    {
        return idCardNumber;
    }
    public void setStudentStatus(Long studentStatus)
    {
        this.studentStatus = studentStatus;
    }

    public Long getStudentStatus()
    {
        return studentStatus;
    }
    public void setPhone(String phone)
    {
        this.phone = phone;
    }

    public String getPhone()
    {
        return phone;
    }
    public void setOriginOfStudent(String originOfStudent)
    {
        this.originOfStudent = originOfStudent;
    }

    public String getOriginOfStudent()
    {
        return originOfStudent;
    }
    public void setGraduatedFrom(String graduatedFrom)
    {
        this.graduatedFrom = graduatedFrom;
    }

    public String getGraduatedFrom()
    {
        return graduatedFrom;
    }
    public void setProfessionId(Long professionId)
    {
        this.professionId = professionId;
    }

    public Long getProfessionId()
    {
        return professionId;
    }
    public void setProfessionName(String professionName)
    {
        this.professionName = professionName;
    }

    public String getProfessionName()
    {
        return professionName;
    }
    public void setClassId(Long classId)
    {
        this.classId = classId;
    }

    public Long getClassId()
    {
        return classId;
    }
    public void setClassName(String className)
    {
        this.className = className;
    }

    public String getClassName()
    {
        return className;
    }
    public void setInsuranceIsBuy(Long insuranceIsBuy)
    {
        this.insuranceIsBuy = insuranceIsBuy;
    }

    public Long getInsuranceIsBuy()
    {
        return insuranceIsBuy;
    }

    public Long getRoomId() {
        return roomId;
    }

    public void setRoomId(Long roomId) {
        this.roomId = roomId;
    }

    public void setUniformIsHandOut(Long uniformIsHandOut)
    {
        this.uniformIsHandOut = uniformIsHandOut;
    }

    public Long getUniformIsHandOut()
    {
        return uniformIsHandOut;
    }
    public void setTextbookIsHandOut(Long textbookIsHandOut)
    {
        this.textbookIsHandOut = textbookIsHandOut;
    }

    public Long getTextbookIsHandOut()
    {
        return textbookIsHandOut;
    }
    public void setScore(Long score)
    {
        this.score = score;
    }

    public Long getScore()
    {
        return score;
    }
    public void setScoreBy(String scoreBy)
    {
        this.scoreBy = scoreBy;
    }

    public String getScoreBy()
    {
        return scoreBy;
    }
    public void setCompanyName(String companyName)
    {
        this.companyName = companyName;
    }

    public String getCompanyName()
    {
        return companyName;
    }
    public void setEntryDate(Date entryDate)
    {
        this.entryDate = entryDate;
    }

    public Date getEntryDate()
    {
        return entryDate;
    }
    public void setCompanyAddress(String companyAddress)
    {
        this.companyAddress = companyAddress;
    }

    public String getCompanyAddress()
    {
        return companyAddress;
    }
    public void setContactName(String contactName)
    {
        this.contactName = contactName;
    }

    public String getContactName()
    {
        return contactName;
    }
    public void setCompanyPhone(String companyPhone)
    {
        this.companyPhone = companyPhone;
    }

    public String getCompanyPhone()
    {
        return companyPhone;
    }
    public void setPoorHouseholdsIs(Long poorHouseholdsIs)
    {
        this.poorHouseholdsIs = poorHouseholdsIs;
    }

    public Long getPoorHouseholdsIs()
    {
        return poorHouseholdsIs;
    }
    public void setRegisterDate(Date registerDate)
    {
        this.registerDate = registerDate;
    }

    public Date getRegisterDate()
    {
        return registerDate;
    }
    public void setEnrollmentDate(Date enrollmentDate)
    {
        this.enrollmentDate = enrollmentDate;
    }

    public Date getEnrollmentDate()
    {
        return enrollmentDate;
    }
    public void setReceivableIncidentals(BigDecimal receivableIncidentals)
    {
        this.receivableIncidentals = receivableIncidentals;
    }

    public BigDecimal getReceivableIncidentals()
    {
        return receivableIncidentals;
    }
    public void setReceivableQuarterage(BigDecimal receivableQuarterage)
    {
        this.receivableQuarterage = receivableQuarterage;
    }

    public BigDecimal getReceivableQuarterage()
    {
        return receivableQuarterage;
    }
    public void setOfficialIncidentals(BigDecimal officialIncidentals)
    {
        this.officialIncidentals = officialIncidentals;
    }

    public BigDecimal getOfficialIncidentals()
    {
        return officialIncidentals;
    }
    public void setIncidentalsBillNo(String incidentalsBillNo)
    {
        this.incidentalsBillNo = incidentalsBillNo;
    }

    public String getIncidentalsBillNo()
    {
        return incidentalsBillNo;
    }
    public void setOfficialQuarterage(BigDecimal officialQuarterage)
    {
        this.officialQuarterage = officialQuarterage;
    }

    public BigDecimal getOfficialQuarterage()
    {
        return officialQuarterage;
    }
    public void setQuarterageBillNo(String quarterageBillNo)
    {
        this.quarterageBillNo = quarterageBillNo;
    }

    public String getQuarterageBillNo()
    {
        return quarterageBillNo;
    }
    public void setChargerName(String chargerName)
    {
        this.chargerName = chargerName;
    }

    public String getChargerName()
    {
        return chargerName;
    }
    public void setPaymentDate(Date paymentDate)
    {
        this.paymentDate = paymentDate;
    }

    public Date getPaymentDate()
    {
        return paymentDate;
    }
    public void setDrawer(String drawer)
    {
        this.drawer = drawer;
    }

    public String getDrawer()
    {
        return drawer;
    }
    public void setContactTeacher(String contactTeacher)
    {
        this.contactTeacher = contactTeacher;
    }

    public String getContactTeacher()
    {
        return contactTeacher;
    }
    public void setIncidentalsBillSerial(String incidentalsBillSerial)
    {
        this.incidentalsBillSerial = incidentalsBillSerial;
    }

    public String getIncidentalsBillSerial()
    {
        return incidentalsBillSerial;
    }
    public void setFirstLowHalfIs(Long firstLowHalfIs)
    {
        this.firstLowHalfIs = firstLowHalfIs;
    }

    public Long getFirstLowHalfIs()
    {
        return firstLowHalfIs;
    }
    public void setSecondUpHalfIs(Long secondUpHalfIs)
    {
        this.secondUpHalfIs = secondUpHalfIs;
    }

    public Long getSecondUpHalfIs()
    {
        return secondUpHalfIs;
    }
    public void setSecondLowHalfIs(Long secondLowHalfIs)
    {
        this.secondLowHalfIs = secondLowHalfIs;
    }

    public Long getSecondLowHalfIs()
    {
        return secondLowHalfIs;
    }
    public void setThirdUpHalfIs(Long thirdUpHalfIs)
    {
        this.thirdUpHalfIs = thirdUpHalfIs;
    }

    public Long getThirdUpHalfIs()
    {
        return thirdUpHalfIs;
    }
    public void setThirdLowHalfIs(Long thirdLowHalfIs)
    {
        this.thirdLowHalfIs = thirdLowHalfIs;
    }

    public Long getThirdLowHalfIs()
    {
        return thirdLowHalfIs;
    }
    public void setChargeTimes(Long chargeTimes)
    {
        this.chargeTimes = chargeTimes;
    }

    public Long getChargeTimes()
    {
        return chargeTimes;
    }

    public Date getShouldRegisterDate() {
        return shouldRegisterDate;
    }

    public void setShouldRegisterDate(Date shouldRegisterDate) {
        this.shouldRegisterDate = shouldRegisterDate;
    }

    public String getPaymentMethod() {
        return paymentMethod;
    }

    public void setPaymentMethod(String paymentMethod) {
        this.paymentMethod = paymentMethod;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public Long getCollegeId() {
        return collegeId;
    }

    public void setCollegeId(Long collegeId) {
        this.collegeId = collegeId;
    }

    public String getCollegeName() {
        return collegeName;
    }

    public String getStudentNumber() {
        return studentNumber;
    }

    public void setStudentNumber(String studentNumber) {
        this.studentNumber = studentNumber;
    }

    public void setCollegeName(String collegeName) {
        this.collegeName = collegeName;
    }

    public BigDecimal getReceivableTotal() {
        return receivableTotal;
    }

    public void setReceivableTotal(BigDecimal receivableTotal) {
        this.receivableTotal = receivableTotal;
    }

    public BigDecimal getOfficialTotal() {
        return officialTotal;
    }

    public void setOfficialTotal(BigDecimal officialTotal) {
        this.officialTotal = officialTotal;
    }

    public String getRoomName() {
        return roomName;
    }

    public void setRoomName(String roomName) {
        this.roomName = roomName;
    }

    public String getBuildingName() {
        return buildingName;
    }

    public void setBuildingName(String buildingName) {
        this.buildingName = buildingName;
    }

    public BigDecimal getFirstLowFees() {
        return firstLowFees;
    }

    public void setFirstLowFees(BigDecimal firstLowFees) {
        this.firstLowFees = firstLowFees;
    }

    public BigDecimal getSecondUpFees() {
        return secondUpFees;
    }

    public void setSecondUpFees(BigDecimal secondUpFees) {
        this.secondUpFees = secondUpFees;
    }

    public BigDecimal getSecondLowFees() {
        return secondLowFees;
    }

    public void setSecondLowFees(BigDecimal secondLowFees) {
        this.secondLowFees = secondLowFees;
    }

    public BigDecimal getThirdUpFees() {
        return thirdUpFees;
    }

    public void setThirdUpFees(BigDecimal thirdUpFees) {
        this.thirdUpFees = thirdUpFees;
    }

    public BigDecimal getThirdLowFees() {
        return thirdLowFees;
    }

    public void setThirdLowFees(BigDecimal thirdLowFees) {
        this.thirdLowFees = thirdLowFees;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Integer getQuitApplyStatus() {
        return quitApplyStatus;
    }

    public void setQuitApplyStatus(Integer quitApplyStatus) {
        this.quitApplyStatus = quitApplyStatus;
    }

    public Integer getOutApplyStatus() {
        return outApplyStatus;
    }

    public void setOutApplyStatus(Integer outApplyStatus) {
        this.outApplyStatus = outApplyStatus;
    }

    public Integer getBookApplyStatus() {
        return bookApplyStatus;
    }

    public void setBookApplyStatus(Integer bookApplyStatus) {
        this.bookApplyStatus = bookApplyStatus;
    }

    public String getDelFlag() {
        return delFlag;
    }

    public void setDelFlag(String delFlag) {
        this.delFlag = delFlag;
    }

    public Integer getQuiltIsHandOut() {
        return quiltIsHandOut;
    }

    public void setQuiltIsHandOut(Integer quiltIsHandOut) {
        this.quiltIsHandOut = quiltIsHandOut;
    }

    public BigDecimal getBeddingFee() {
        return beddingFee;
    }

    public void setBeddingFee(BigDecimal beddingFee) {
        this.beddingFee = beddingFee;
    }

    public Integer getRoomType() {
        return roomType;
    }

    public void setRoomType(Integer roomType) {
        this.roomType = roomType;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public Date getTicketDate() {
        return ticketDate;
    }

    public void setTicketDate(Date ticketDate) {
        this.ticketDate = ticketDate;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("id", getId())
            .append("studentName", getStudentName())
            .append("sex", getSex())
            .append("educationBackground", getEducationBackground())
            .append("freshStudent", getFreshStudent())
            .append("idCardNumber", getIdCardNumber())
            .append("studentStatus", getStudentStatus())
            .append("phone", getPhone())
            .append("originOfStudent", getOriginOfStudent())
            .append("graduatedFrom", getGraduatedFrom())
            .append("professionId", getProfessionId())
            .append("professionName", getProfessionName())
            .append("classId", getClassId())
            .append("className", getClassName())
            .append("insuranceIsBuy", getInsuranceIsBuy())
            .append("roomId", getRoomId())
            .append("uniformIsHandOut", getUniformIsHandOut())
            .append("textbookIsHandOut", getTextbookIsHandOut())
            .append("score", getScore())
            .append("scoreBy", getScoreBy())
            .append("remark", getRemark())
            .append("companyName", getCompanyName())
            .append("entryDate", getEntryDate())
            .append("companyAddress", getCompanyAddress())
            .append("contactName", getContactName())
            .append("companyPhone", getCompanyPhone())
            .append("poorHouseholdsIs", getPoorHouseholdsIs())
            .append("registerDate", getRegisterDate())
            .append("enrollmentDate", getEnrollmentDate())
            .append("receivableIncidentals", getReceivableIncidentals())
            .append("receivableQuarterage", getReceivableQuarterage())
            .append("officialIncidentals", getOfficialIncidentals())
            .append("incidentalsBillNo", getIncidentalsBillNo())
            .append("officialQuarterage", getOfficialQuarterage())
            .append("quarterageBillNo", getQuarterageBillNo())
            .append("chargerName", getChargerName())
            .append("paymentDate", getPaymentDate())
            .append("drawer", getDrawer())
            .append("contactTeacher", getContactTeacher())
            .append("incidentalsBillSerial", getIncidentalsBillSerial())
            .append("firstLowHalfIs", getFirstLowHalfIs())
            .append("secondUpHalfIs", getSecondUpHalfIs())
            .append("secondLowHalfIs", getSecondLowHalfIs())
            .append("thirdUpHalfIs", getThirdUpHalfIs())
            .append("thirdLowHalfIs", getThirdLowHalfIs())
            .append("chargeTimes", getChargeTimes())
            .append("createBy", getCreateBy())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .toString();
    }
}
