package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.vo.FinanceExportVo;
import com.ruoyi.system.domain.vo.RoomStudentVo;
import com.ruoyi.system.domain.vo.StudentGraduationStatusVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 学生Mapper接口
 *
 * @author liql
 * @date 2021-03-23
 */
public interface StuBaseInfoMapper
{
    /**
     * 查询学生
     *
     * @param id 学生ID
     * @return 学生
     */
    public StuBaseInfo selectStuBaseInfoById(Long id);

    /**
     * 查询学生列表
     *
     * @param stuBaseInfo 学生
     * @return 学生集合
     */
    public List<StuBaseInfo> selectStuBaseInfoList(StuBaseInfo stuBaseInfo);

    /**
     * 新增学生
     *
     * @param stuBaseInfo 学生
     * @return 结果
     */
    public int insertStuBaseInfo(StuBaseInfo stuBaseInfo);

    /**
     * 修改学生
     *
     * @param stuBaseInfo 学生
     * @return 结果
     */
    public int updateStuBaseInfo(StuBaseInfo stuBaseInfo);

    /**
     * 根据身份证修改
     * @param stuBaseInfo
     * @return
     */
    public int updateStuBaseInfoByNumber(StuBaseInfo stuBaseInfo);

    /**
     * 删除学生
     *
     * @param id 学生ID
     * @return 结果
     */
    public int deleteStuBaseInfoById(Long id);

    /**
     * 批量删除学生
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteStuBaseInfoByIds(Long[] ids);

    /**
     * 根据身份证号获取学生信息
     * @param idCardNumber
     * @return StuBaseInfo 对象
     */
    public StuBaseInfo selectStudentByIDNumber(@Param("idCardNumber") String idCardNumber);

    /**
     * 查询要毕业的学生
     * @return
     */
    public List<StudentGraduationStatusVo> selectGraduationStudent();

    /**
     * 更新学生的状态
     * @param vo
     * @return
     */
    public int updateStudentStatus(StudentGraduationStatusVo vo);

    /**
     * @Description 导出学生财务信息
     * @param stuBaseInfo
     * @return java.util.List<com.ruoyi.system.domain.vo.FinanceExportVo>
     */
    public List<FinanceExportVo> selectStuFinanceInfoList(StuBaseInfo stuBaseInfo);

    /**
     * @Description 根据寝室id查询学生列表
     * @param roomId
     * @return java.util.List<com.ruoyi.system.domain.vo.RoomStudentVo>
     */
    public List<RoomStudentVo> selectStudentByRoomId(@Param("roomId") Long roomId);


    /**
     * 逻辑删除往届学生
     * @param vo
     * @return
     */
    public int deleteOldStudent(StudentGraduationStatusVo vo);
}
