package com.ruoyi.system.service;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.vo.FinanceExportVo;
import com.ruoyi.system.domain.vo.RoomStudentVo;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 学生Service接口
 *
 * @author liql
 * @date 2021-03-23
 */
public interface IStuBaseInfoService
{
    /**
     * 查询学生
     *
     * @param id 学生ID
     * @return 学生
     */
    public StuBaseInfo selectStuBaseInfoById(Long id);

    /**
     * 查询学生列表
     *
     * @param stuBaseInfo 学生
     * @return 学生集合
     */
    public List<StuBaseInfo> selectStuBaseInfoList(StuBaseInfo stuBaseInfo);

    /**
     * 新增学生
     *
     * @param stuBaseInfo 学生
     * @return 结果
     */
    public int insertStuBaseInfo(StuBaseInfo stuBaseInfo);

    /**
     * 修改学生
     *
     * @param stuBaseInfo 学生
     * @return 结果
     */
    public int updateStuBaseInfo(StuBaseInfo stuBaseInfo);

    /**
     * 批量删除学生
     *
     * @param ids 需要删除的学生ID
     * @return 结果
     */
    public int deleteStuBaseInfoByIds(Long[] ids);

    /**
     * 删除学生信息
     *
     * @param id 学生ID
     * @return 结果
     */
    public int deleteStuBaseInfoById(Long id);

    /**
     *  导入学生数据
     * @param stuBaseInfoList 用户列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importBaseInfo(List<StuBaseInfo> stuBaseInfoList, Boolean isUpdateSupport, String operName);

    /**
     * @Description 学生退学
     * @param ids
     * @return int
     */
    public int dropOutOfSchool(Long[] ids);

    /**
     * @Description 导出学生财务信息
     * @param stuBaseInfo
     * @return java.util.List<com.ruoyi.system.domain.vo.FinanceExportVo>
     */
    public List<FinanceExportVo> selectStuFinanceInfoList(StuBaseInfo stuBaseInfo);

    /**
     * @Description 根据寝室id查询学生列表
     * @param roomId
     * @return java.util.List<com.ruoyi.system.domain.vo.RoomStudentVo>
     */
    public List<RoomStudentVo> selectStudentByRoomId(Long roomId);


}
