package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.system.domain.StuBuilding;
import com.ruoyi.system.domain.StuRoom;
import org.apache.ibatis.annotations.Param;

/**
 * 寝室Service接口
 * 
 * @author liql
 * @date 2021-06-17
 */
public interface IStuRoomService 
{
    /**
     * 查询寝室
     * 
     * @param id 寝室ID
     * @return 寝室
     */
    public StuRoom selectStuRoomById(Long id);

    /**
     * 查询寝室列表
     * 
     * @param stuRoom 寝室
     * @return 寝室集合
     */
    public List<StuRoom> selectStuRoomList(StuRoom stuRoom);

    /**
     * 新增寝室
     * 
     * @param stuRoom 寝室
     * @return 结果
     */
    public int insertStuRoom(StuRoom stuRoom);

    /**
     * 修改寝室
     * 
     * @param stuRoom 寝室
     * @return 结果
     */
    public int updateStuRoom(StuRoom stuRoom);

    /**
     * 批量删除寝室
     * 
     * @param ids 需要删除的寝室ID
     * @return 结果
     */
    public int deleteStuRoomByIds(Long[] ids);

    /**
     * 删除寝室信息
     * 
     * @param id 寝室ID
     * @return 结果
     */
    public int deleteStuRoomById(Long id);

    /**
     * @Description 根据寝室名查询寝室
     * @param roomName
     * @return int
     */
    public StuRoom queryRoomByName(String roomName);

    /**
     * @Description 根据楼宇id查询寝室列表
     * @param buildingId
     * @return java.util.List<com.ruoyi.system.domain.StuRoom>
     */
    public List<StuRoom> queryRoomByBuildingId(Long buildingId,Integer roomType);


    /**
     *  导入寝室数据
     * @param stuRoomList 用户列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importRooms(List<StuRoom> stuRoomList, Boolean isUpdateSupport, String operName);
}
