package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.exception.CustomException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.StuProfession;
import com.ruoyi.system.domain.vo.FinanceExportVo;
import com.ruoyi.system.domain.vo.RoomStudentVo;
import com.ruoyi.system.domain.vo.StudentGraduationStatusVo;
import com.ruoyi.system.mapper.StuBaseInfoMapper;
import com.ruoyi.system.mapper.StuProfessionMapper;
import com.ruoyi.system.service.IStuBaseInfoService;
import org.apache.commons.lang3.ObjectUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 学生Service业务层处理
 *
 * @author liql
 * @date 2021-03-23
 */
@Service
public class StuBaseInfoServiceImpl implements IStuBaseInfoService
{
    private static final Logger log = LoggerFactory.getLogger(StuBaseInfoServiceImpl.class);
    @Resource
    private StuBaseInfoMapper stuBaseInfoMapper;
    @Resource
    private StuProfessionMapper stuProfessionMapper;

    /**
     * 查询学生
     *
     * @param id 学生ID
     * @return 学生
     */
    @Override
    public StuBaseInfo selectStuBaseInfoById(Long id)
    {
        return stuBaseInfoMapper.selectStuBaseInfoById(id);
    }

    /**
     * 查询学生列表
     *
     * @param stuBaseInfo 学生
     * @return 学生
     */
    @Override
    public List<StuBaseInfo> selectStuBaseInfoList(StuBaseInfo stuBaseInfo)
    {
        return stuBaseInfoMapper.selectStuBaseInfoList(stuBaseInfo);
    }

    /**
     * 新增学生
     *
     * @param stuBaseInfo 学生
     * @return 结果
     */
    @Override
    public int insertStuBaseInfo(StuBaseInfo stuBaseInfo)
    {
        stuBaseInfo.setCreateTime(DateUtils.getNowDate());
        stuBaseInfo.setUpdateTime(DateUtils.getNowDate());
        String idCardNumber = stuBaseInfo.getIdCardNumber();
        StuBaseInfo t = stuBaseInfoMapper.selectStudentByIDNumber(idCardNumber);
        if(ObjectUtils.isEmpty(t)){
            stuBaseInfoMapper.insertStuBaseInfo(stuBaseInfo);
        }else{
            throw new CustomException("身份证号为"+idCardNumber+"的学生已存在");
        }

        return 1;
    }

    /**
     * 修改学生
     *
     * @param stuBaseInfo 学生
     * @return 结果
     */
    @Override
    public int updateStuBaseInfo(StuBaseInfo stuBaseInfo)
    {
        stuBaseInfo.setUpdateTime(DateUtils.getNowDate());
        Long studentStatus = stuBaseInfo.getStudentStatus()==null?0:stuBaseInfo.getStudentStatus();


        if(studentStatus>=2 && studentStatus<8){
            Long chargeTimes = 1L;
            Long firstLowHalfIs = stuBaseInfo.getFirstLowHalfIs()==null?0:stuBaseInfo.getFirstLowHalfIs();
            Long secondUpHalfIs = stuBaseInfo.getSecondUpHalfIs()==null?0:stuBaseInfo.getSecondUpHalfIs();
            Long secondLowHalfIs = stuBaseInfo.getSecondLowHalfIs()==null?0:stuBaseInfo.getSecondLowHalfIs();
            Long thirdUpHalfIs = stuBaseInfo.getThirdUpHalfIs()==null?0:stuBaseInfo.getThirdUpHalfIs();
            Long thirdLowHalfIs = stuBaseInfo.getThirdLowHalfIs()==null?0:stuBaseInfo.getThirdLowHalfIs();

            chargeTimes+=firstLowHalfIs;
            chargeTimes+=secondUpHalfIs;
            chargeTimes+=secondLowHalfIs;
            chargeTimes+=thirdUpHalfIs;
            chargeTimes+=thirdLowHalfIs;

            stuBaseInfo.setChargeTimes(chargeTimes);
            //stuBaseInfo.setStudentStatus(++chargeTimes);
        }



        return stuBaseInfoMapper.updateStuBaseInfo(stuBaseInfo);
    }

    /**
     * 批量删除学生
     *
     * @param ids 需要删除的学生ID
     * @return 结果
     */
    @Override
    public int deleteStuBaseInfoByIds(Long[] ids)
    {
        return stuBaseInfoMapper.deleteStuBaseInfoByIds(ids);
    }

    /**
     * 删除学生信息
     *
     * @param id 学生ID
     * @return 结果
     */
    @Override
    public int deleteStuBaseInfoById(Long id)
    {
        return stuBaseInfoMapper.deleteStuBaseInfoById(id);
    }


    /**
     * 导入用户数据
     *
     * @param stuBaseInfoList        用户数据列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName        操作用户
     * @return 结果
     */
    @Override
    public String importBaseInfo(List<StuBaseInfo> stuBaseInfoList, Boolean isUpdateSupport, String operName) {
        if (StringUtils.isNull(stuBaseInfoList) || stuBaseInfoList.size() == 0) {
            throw new CustomException("导入用户数据不能为空！");
        }
        int successNum = 0;
        int failureNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (StuBaseInfo student : stuBaseInfoList) {
            String idCardNumber = student.getIdCardNumber();
            try {
                // 验证是否存在这个用户
                StuBaseInfo t = stuBaseInfoMapper.selectStudentByIDNumber(idCardNumber);
                if (ObjectUtils.isEmpty(t)) {
                    String professionName = student.getProfessionName();
                    StuProfession profession = stuProfessionMapper.selectProfessionByProfessionName(professionName);
                    if(null!=profession){
                        student.setProfessionId(profession.getId());
                        student.setCreateBy(operName);
                        this.insertStuBaseInfo(student);
                        successNum++;
                        successMsg.append("<br/>" + successNum + "、身份证号 " + idCardNumber + " 导入成功");
                    }else{
                        failureNum++;
                        failureMsg.append("<br/>" + failureNum + "、身份证号 " + idCardNumber + " 所选的专业不正在");
                    }

                } else if (isUpdateSupport) {
                    student.setUpdateBy(operName);
                    stuBaseInfoMapper.updateStuBaseInfoByNumber(student);
                    successNum++;
                    successMsg.append("<br/>" + successNum + "、身份证号 " + idCardNumber + " 更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>" + failureNum + "、身份证号 " + idCardNumber + " 已存在");
                }
            } catch (Exception e) {
                failureNum++;
                String msg = "<br/>" + failureNum + "、身份证号 " + idCardNumber + " 导入失败：";
                failureMsg.append(msg + e.getMessage());
                log.error(msg, e);
            }
        }
        if (failureNum > 0) {
            failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据格式不正确，错误如下：");
            throw new CustomException(failureMsg.toString());
        } else {
            successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
        }
        return successMsg.toString();
    }

    /**
     * @param ids
     * @return int
     * @Description 学生退学
     */
    @Override
    public int dropOutOfSchool(Long[] ids) {
        int i=0;
        for(Long id:ids){
            StudentGraduationStatusVo vo = new StudentGraduationStatusVo();
            vo.setId(id);
            vo.setStudentStatus(11L);
           i =  stuBaseInfoMapper.updateStudentStatus(vo);
        }
        return i;
    }

    /**
     * @param stuBaseInfo
     * @return java.util.List<com.ruoyi.system.domain.vo.FinanceExportVo>
     * @Description 导出学生财务信息
     */
    @Override
    public List<FinanceExportVo> selectStuFinanceInfoList(StuBaseInfo stuBaseInfo) {
        return stuBaseInfoMapper.selectStuFinanceInfoList(stuBaseInfo);
    }

    /**
     * @param roomId
     * @return java.util.List<com.ruoyi.system.domain.vo.RoomStudentVo>
     * @Description 根据寝室id查询学生列表
     */
    @Override
    public List<RoomStudentVo> selectStudentByRoomId(Long roomId) {
        return stuBaseInfoMapper.selectStudentByRoomId(roomId);
    }
}
