package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.exception.CustomException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.StuTextBook;
import com.ruoyi.system.domain.param.ApplyListParam;
import com.ruoyi.system.domain.vo.ApplyListVo;
import com.ruoyi.system.mapper.StuBaseInfoMapper;
import com.ruoyi.system.mapper.StuTextBookMapper;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuBookApplyMapper;
import com.ruoyi.system.domain.StuBookApply;
import com.ruoyi.system.service.IStuBookApplyService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 教材申请Service业务层处理
 * 
 * @author liql
 * @date 2021-09-27
 */
@Service
public class StuBookApplyServiceImpl implements IStuBookApplyService 
{
    @Autowired
    private StuBookApplyMapper stuBookApplyMapper;
    @Autowired
    private StuTextBookMapper stuTextBookMapper;
    @Autowired
    private StuBaseInfoMapper stuBaseInfoMapper;

    /**
     * 查询教材申请
     * 
     * @param id 教材申请ID
     * @return 教材申请
     */
    @Override
    public StuBookApply selectStuBookApplyById(Long id)
    {
        return stuBookApplyMapper.selectStuBookApplyById(id);
    }

    /**
     * 查询教材申请列表
     * 
     * @param param 教材申请
     * @return 教材申请
     */
    @Override
    public List<ApplyListVo> selectStuBookApplyList(ApplyListParam param)
    {
        return stuBookApplyMapper.selectStuBookApplyList(param);
    }

    /**
     * 新增教材申请
     * 
     * @param stuBookApply 教材申请
     * @return 结果
     */
    @Override
    @Transactional
    public int insertStuBookApply(StuBookApply stuBookApply)
    {
        stuBookApply.setCreateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuBookApply.setCreateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(stuBookApply.getStudentId());
        student.setBookApplyStatus(1);
        stuBaseInfoMapper.updateStuBaseInfo(student);

        return stuBookApplyMapper.insertStuBookApply(stuBookApply);
    }

    /**
     * 修改教材申请
     * 
     * @param stuBookApply 教材申请
     * @return 结果
     */
    @Override
    @Transactional
    public int updateStuBookApply(StuBookApply stuBookApply)
    {
        stuBookApply.setUpdateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuBookApply.setUpdateBy(String.valueOf(userId));
        Long classId = stuBookApply.getClassId();

        List<StuTextBook> list =   stuTextBookMapper.selectTextBookByClassId(classId);
        for (StuTextBook book:list) {
            Long amount = book.getAmount();
            if (amount<=0){
                throw new CustomException(book.getName()+" 书本的数量不足请核实");
            }else{
                book.setAmount(amount-1);
            }

            stuTextBookMapper.updateStuTextBook(book);
        }

        return stuBookApplyMapper.updateStuBookApply(stuBookApply);
    }

    /**
     * 批量删除教材申请
     * 
     * @param ids 需要删除的教材申请ID
     * @return 结果
     */
    @Override
    public int deleteStuBookApplyByIds(Long[] ids)
    {
        return stuBookApplyMapper.deleteStuBookApplyByIds(ids);
    }

    /**
     * 删除教材申请信息
     * 
     * @param id 教材申请ID
     * @return 结果
     */
    @Override
    public int deleteStuBookApplyById(Long id)
    {
        return stuBookApplyMapper.deleteStuBookApplyById(id);
    }
}
