package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.param.ClassBookConfigParam;
import com.ruoyi.system.domain.vo.BookConfigVo;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuClassBookConfigMapper;
import com.ruoyi.system.domain.StuClassBookConfig;
import com.ruoyi.system.service.IStuClassBookConfigService;

/**
 * 教材配置Service业务层处理
 * 
 * @author liql
 * @date 2021-09-27
 */
@Service
public class StuClassBookConfigServiceImpl implements IStuClassBookConfigService 
{
    @Autowired
    private StuClassBookConfigMapper stuClassBookConfigMapper;

    /**
     * 查询教材配置
     * 
     * @param classId 教材配置ID
     * @return 教材配置
     */
    @Override
    public StuClassBookConfig selectStuClassBookConfigById(Long classId)
    {
        return stuClassBookConfigMapper.selectStuClassBookConfigById(classId);
    }

    /**
     * 查询教材配置列表
     * 
     * @param classId 教材配置
     * @return 教材配置
     */
    @Override
    public List<BookConfigVo> selectClassBookConfigListByClassId(Long classId)
    {
        return stuClassBookConfigMapper.selectClassBookConfigListByClassId(classId);
    }

    /**
     * 新增教材配置
     * 
     * @param stuClassBookConfig 教材配置
     * @return 结果
     */
    @Override
    public int insertStuClassBookConfig(StuClassBookConfig stuClassBookConfig)
    {
        stuClassBookConfig.setCreateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuClassBookConfig.setCreateBy(String.valueOf(userId));

        List<Long> textBookIdList = stuClassBookConfig.getTextBookIdList();
        for (Long textBookId:textBookIdList) {
            stuClassBookConfig.setTextBookId(textBookId);
            StuClassBookConfig config =  stuClassBookConfigMapper.selectClassBookConfigByClassIdAndBookId(stuClassBookConfig);
            if(ObjectUtils.isEmpty(config)) {
                stuClassBookConfigMapper.insertStuClassBookConfig(stuClassBookConfig);
            }
        }
        return textBookIdList.size();
    }

    /**
     * 修改教材配置
     * 
     * @param stuClassBookConfig 教材配置
     * @return 结果
     */
    @Override
    public int updateStuClassBookConfig(StuClassBookConfig stuClassBookConfig)
    {
        stuClassBookConfig.setCreateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuClassBookConfig.setCreateBy(String.valueOf(userId));

        List<Long> textBookIdList = stuClassBookConfig.getTextBookIdList();
        for (Long textBookId:textBookIdList) {
            stuClassBookConfig.setTextBookId(textBookId);
            StuClassBookConfig config =  stuClassBookConfigMapper.selectClassBookConfigByClassIdAndBookId(stuClassBookConfig);
            if(ObjectUtils.isEmpty(config)) {
                stuClassBookConfigMapper.insertStuClassBookConfig(stuClassBookConfig);
            }
        }
        return textBookIdList.size();
    }

    /**
     * 批量删除教材配置
     * 
     * @param params 教材配置对象参数数组
     * @return 结果
     */
    @Override
    public int deleteStuClassBookConfigByParams(ClassBookConfigParam[] params)
    {
        return stuClassBookConfigMapper.deleteStuClassBookConfigByParams(params);
    }

    /**
     * 删除教材配置信息
     * 
     * @param param 教材配置对象参数
     * @return 结果
     */
    @Override
    public int deleteStuClassBookConfigByParam(ClassBookConfigParam param)
    {
        return stuClassBookConfigMapper.deleteStuClassBookConfigByParam(param);
    }
}
