package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuClassMapper;
import com.ruoyi.system.domain.StuClass;
import com.ruoyi.system.service.IStuClassService;

/**
 * 班级Service业务层处理
 *
 * @author liql
 * @date 2021-03-23
 */
@Service
public class StuClassServiceImpl implements IStuClassService
{
    @Autowired
    private StuClassMapper stuClassMapper;

    /**
     * 查询班级
     *
     * @param id 班级ID
     * @return 班级
     */
    @Override
    public StuClass selectStuClassById(Long id)
    {
        return stuClassMapper.selectStuClassById(id);
    }

    /**
     * 查询班级列表
     *
     * @param stuClass 班级
     * @return 班级
     */
    @Override
    public List<StuClass> selectStuClassList(StuClass stuClass)
    {
        return stuClassMapper.selectStuClassList(stuClass);
    }

    /**
     * 新增班级
     *
     * @param stuClass 班级
     * @return 结果
     */
    @Override
    public int insertStuClass(StuClass stuClass)
    {
        stuClass.setCreateTime(DateUtils.getNowDate());
        return stuClassMapper.insertStuClass(stuClass);
    }

    /**
     * 修改班级
     *
     * @param stuClass 班级
     * @return 结果
     */
    @Override
    public int updateStuClass(StuClass stuClass)
    {
        stuClass.setUpdateTime(DateUtils.getNowDate());
        return stuClassMapper.updateStuClass(stuClass);
    }

    /**
     * 批量删除班级
     *
     * @param ids 需要删除的班级ID
     * @return 结果
     */
    @Override
    public int deleteStuClassByIds(Long[] ids)
    {
        return stuClassMapper.deleteStuClassByIds(ids);
    }

    /**
     * 删除班级信息
     *
     * @param id 班级ID
     * @return 结果
     */
    @Override
    public int deleteStuClassById(Long id)
    {
        return stuClassMapper.deleteStuClassById(id);
    }

    /**
     * 根据专业id查询班级列表
     *
     * @param professionId
     * @return
     */
    @Override
    public List<Map<String,Object>> queryList(Long professionId) {
        return stuClassMapper.queryList(professionId);
    }

    /**
     * @param className
     * @return com.ruoyi.system.domain.StuClass
     * @Description 根据班级名查询班级
     */
    @Override
    public StuClass queryClassByName(String className) {
        return stuClassMapper.queryClassByName(className);
    }
}
