package com.ruoyi.system.service.impl;

import java.util.List;
import java.util.Map;

import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuDepartmentMapper;
import com.ruoyi.system.domain.StuDepartment;
import com.ruoyi.system.service.IStuDepartmentService;

/**
 * 科系Service业务层处理
 *
 * @author liql
 * @date 2021-03-23
 */
@Service
public class StuDepartmentServiceImpl implements IStuDepartmentService
{
    @Autowired
    private StuDepartmentMapper stuDepartmentMapper;

    /**
     * 查询科系
     *
     * @param id 科系ID
     * @return 科系
     */
    @Override
    public StuDepartment selectStuDepartmentById(Long id)
    {
        return stuDepartmentMapper.selectStuDepartmentById(id);
    }

    /**
     * 查询科系列表
     *
     * @param stuDepartment 科系
     * @return 科系
     */
    @Override
    public List<StuDepartment> selectStuDepartmentList(StuDepartment stuDepartment)
    {
        return stuDepartmentMapper.selectStuDepartmentList(stuDepartment);
    }

    /**
     * 新增科系
     *
     * @param stuDepartment 科系
     * @return 结果
     */
    @Override
    public int insertStuDepartment(StuDepartment stuDepartment)
    {
        stuDepartment.setCreateTime(DateUtils.getNowDate());
        return stuDepartmentMapper.insertStuDepartment(stuDepartment);
    }

    /**
     * 修改科系
     *
     * @param stuDepartment 科系
     * @return 结果
     */
    @Override
    public int updateStuDepartment(StuDepartment stuDepartment)
    {
        stuDepartment.setUpdateTime(DateUtils.getNowDate());
        return stuDepartmentMapper.updateStuDepartment(stuDepartment);
    }

    /**
     * 批量删除科系
     *
     * @param ids 需要删除的科系ID
     * @return 结果
     */
    @Override
    public int deleteStuDepartmentByIds(Long[] ids)
    {
        return stuDepartmentMapper.deleteStuDepartmentByIds(ids);
    }

    /**
     * 删除科系信息
     *
     * @param id 科系ID
     * @return 结果
     */
    @Override
    public int deleteStuDepartmentById(Long id)
    {
        return stuDepartmentMapper.deleteStuDepartmentById(id);
    }

    /**
     * 根据学院id查询科系列表
     *
     * @param collegeId
     * @return
     */
    @Override
    public List<Map<String,Object>> queryList(Long collegeId) {
        return stuDepartmentMapper.queryList(collegeId);
    }
}
