package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.param.ApplyListParam;
import com.ruoyi.system.domain.vo.ApplyListVo;
import com.ruoyi.system.domain.vo.StudentGraduationStatusVo;
import com.ruoyi.system.mapper.StuBaseInfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuOutSchoolApplyMapper;
import com.ruoyi.system.domain.StuOutSchoolApply;
import com.ruoyi.system.service.IStuOutSchoolApplyService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 失学申请Service业务层处理
 * 
 * @author liql
 * @date 2021-09-27
 */
@Service
public class StuOutSchoolApplyServiceImpl implements IStuOutSchoolApplyService 
{
    @Autowired
    private StuOutSchoolApplyMapper stuOutSchoolApplyMapper;
    @Autowired
    private StuBaseInfoMapper stuBaseInfoMapper;

    /**
     * 查询失学申请
     * 
     * @param id 失学申请ID
     * @return 失学申请
     */
    @Override
    public StuOutSchoolApply selectStuOutSchoolApplyById(Long id)
    {
        return stuOutSchoolApplyMapper.selectStuOutSchoolApplyById(id);
    }

    /**
     * 查询失学申请列表
     * 
     * @param param 失学申请
     * @return 失学申请
     */
    @Override
    public List<ApplyListVo> selectStuOutSchoolApplyList(ApplyListParam param)
    {
        return stuOutSchoolApplyMapper.selectStuOutSchoolApplyList(param);
    }

    /**
     * 新增失学申请
     * 
     * @param stuOutSchoolApply 失学申请
     * @return 结果
     */
    @Override
    public int insertStuOutSchoolApply(StuOutSchoolApply stuOutSchoolApply)
    {
        stuOutSchoolApply.setCreateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuOutSchoolApply.setCreateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(stuOutSchoolApply.getStudentId());
        student.setOutApplyStatus(1);
        stuBaseInfoMapper.updateStuBaseInfo(student);

        return stuOutSchoolApplyMapper.insertStuOutSchoolApply(stuOutSchoolApply);
    }

    /**
     * 修改失学申请
     * 
     * @param stuOutSchoolApply 失学申请
     * @return 结果
     */
    @Override
    @Transactional
    public int updateStuOutSchoolApply(StuOutSchoolApply stuOutSchoolApply)
    {
        stuOutSchoolApply.setUpdateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuOutSchoolApply.setUpdateBy(String.valueOf(userId));

        StudentGraduationStatusVo student = new StudentGraduationStatusVo();
        student.setId(stuOutSchoolApply.getStudentId());
        student.setStudentStatus(12L);
        stuBaseInfoMapper.updateStudentStatus(student);

        return stuOutSchoolApplyMapper.updateStuOutSchoolApply(stuOutSchoolApply);
    }

    /**
     * 批量删除失学申请
     * 
     * @param ids 需要删除的失学申请ID
     * @return 结果
     */
    @Override
    public int deleteStuOutSchoolApplyByIds(Long[] ids)
    {
        return stuOutSchoolApplyMapper.deleteStuOutSchoolApplyByIds(ids);
    }

    /**
     * 删除失学申请信息
     * 
     * @param id 失学申请ID
     * @return 结果
     */
    @Override
    public int deleteStuOutSchoolApplyById(Long id)
    {
        return stuOutSchoolApplyMapper.deleteStuOutSchoolApplyById(id);
    }
}
