package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.param.ApplyListParam;
import com.ruoyi.system.domain.vo.ApplyListVo;
import com.ruoyi.system.domain.vo.StudentGraduationStatusVo;
import com.ruoyi.system.mapper.StuBaseInfoMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuQuitSchoolApplyMapper;
import com.ruoyi.system.domain.StuQuitSchoolApply;
import com.ruoyi.system.service.IStuQuitSchoolApplyService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 退学申请Service业务层处理
 * 
 * @author liql
 * @date 2021-09-27
 */
@Service
public class StuQuitSchoolApplyServiceImpl implements IStuQuitSchoolApplyService 
{
    @Autowired
    private StuQuitSchoolApplyMapper stuQuitSchoolApplyMapper;
    @Autowired
    private StuBaseInfoMapper stuBaseInfoMapper;

    /**
     * 查询退学申请
     * 
     * @param id 退学申请ID
     * @return 退学申请
     */
    @Override
    public StuQuitSchoolApply selectStuQuitSchoolApplyById(Long id)
    {
        return stuQuitSchoolApplyMapper.selectStuQuitSchoolApplyById(id);
    }

    /**
     * 查询退学申请列表
     * 
     * @param param 退学申请
     * @return 退学申请
     */
    @Override
    public List<ApplyListVo> selectStuQuitSchoolApplyList(ApplyListParam param)
    {
        return stuQuitSchoolApplyMapper.selectStuQuitSchoolApplyList(param);
    }

    /**
     * 新增退学申请
     * 
     * @param stuQuitSchoolApply 退学申请
     * @return 结果
     */
    @Override
    public int insertStuQuitSchoolApply(StuQuitSchoolApply stuQuitSchoolApply)
    {
        stuQuitSchoolApply.setCreateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuQuitSchoolApply.setCreateBy(String.valueOf(userId));

        StuBaseInfo student = new StuBaseInfo();
        student.setUserId(stuQuitSchoolApply.getStudentId());
        student.setQuitApplyStatus(1);
        stuBaseInfoMapper.updateStuBaseInfo(student);

        return stuQuitSchoolApplyMapper.insertStuQuitSchoolApply(stuQuitSchoolApply);
    }

    /**
     * 修改退学申请
     * 
     * @param stuQuitSchoolApply 退学申请
     * @return 结果
     */
    @Override
    @Transactional
    public int updateStuQuitSchoolApply(StuQuitSchoolApply stuQuitSchoolApply)
    {
        stuQuitSchoolApply.setUpdateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuQuitSchoolApply.setUpdateBy(String.valueOf(userId));

        StudentGraduationStatusVo student = new StudentGraduationStatusVo();
        student.setId(stuQuitSchoolApply.getStudentId());
        student.setStudentStatus(11L);
        stuBaseInfoMapper.updateStudentStatus(student);

        return stuQuitSchoolApplyMapper.updateStuQuitSchoolApply(stuQuitSchoolApply);
    }

    /**
     * 批量删除退学申请
     * 
     * @param ids 需要删除的退学申请ID
     * @return 结果
     */
    @Override
    public int deleteStuQuitSchoolApplyByIds(Long[] ids)
    {
        return stuQuitSchoolApplyMapper.deleteStuQuitSchoolApplyByIds(ids);
    }

    /**
     * 删除退学申请信息
     * 
     * @param id 退学申请ID
     * @return 结果
     */
    @Override
    public int deleteStuQuitSchoolApplyById(Long id)
    {
        return stuQuitSchoolApplyMapper.deleteStuQuitSchoolApplyById(id);
    }
}
