package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.exception.CustomException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.StuBaseInfo;
import com.ruoyi.system.domain.StuBuilding;
import com.ruoyi.system.domain.StuProfession;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuRoomMapper;
import com.ruoyi.system.domain.StuRoom;
import com.ruoyi.system.service.IStuRoomService;

/**
 * 寝室Service业务层处理
 * 
 * @author liql
 * @date 2021-06-17
 */
@Service
public class StuRoomServiceImpl implements IStuRoomService 
{
    @Autowired
    private StuRoomMapper stuRoomMapper;

    /**
     * 查询寝室
     * 
     * @param id 寝室ID
     * @return 寝室
     */
    @Override
    public StuRoom selectStuRoomById(Long id)
    {
        return stuRoomMapper.selectStuRoomById(id);
    }

    /**
     * 查询寝室列表
     * 
     * @param stuRoom 寝室
     * @return 寝室
     */
    @Override
    public List<StuRoom> selectStuRoomList(StuRoom stuRoom)
    {
        return stuRoomMapper.selectStuRoomList(stuRoom);
    }

    /**
     * 新增寝室
     * 
     * @param stuRoom 寝室
     * @return 结果
     */
    @Override
    public int insertStuRoom(StuRoom stuRoom)
    {
        stuRoom.setCreateTime(DateUtils.getNowDate());
        return stuRoomMapper.insertStuRoom(stuRoom);
    }

    /**
     * 修改寝室
     * 
     * @param stuRoom 寝室
     * @return 结果
     */
    @Override
    public int updateStuRoom(StuRoom stuRoom)
    {
        stuRoom.setUpdateTime(DateUtils.getNowDate());
        return stuRoomMapper.updateStuRoom(stuRoom);
    }

    /**
     * 批量删除寝室
     * 
     * @param ids 需要删除的寝室ID
     * @return 结果
     */
    @Override
    public int deleteStuRoomByIds(Long[] ids)
    {
        return stuRoomMapper.deleteStuRoomByIds(ids);
    }

    /**
     * 删除寝室信息
     * 
     * @param id 寝室ID
     * @return 结果
     */
    @Override
    public int deleteStuRoomById(Long id)
    {
        return stuRoomMapper.deleteStuRoomById(id);
    }

    /**
     * @param roomName
     * @return int
     * @Description 根据寝室名查询寝室
     */
    @Override
    public StuRoom queryRoomByName(String roomName) {
        return stuRoomMapper.queryRoomByName(roomName);
    }

    /**
     * @param buildingId
     * @return java.util.List<com.ruoyi.system.domain.StuRoom>
     * @Description 根据楼宇id查询寝室列表
     */
    @Override
    public List<StuRoom> queryRoomByBuildingId(Long buildingId,Integer roomType) {
        return stuRoomMapper.queryRoomByBuildingId(buildingId,roomType);
    }


    /**
     *  导入楼宇数据
     * @param stuRoomList 寝室列表
     * @param isUpdateSupport 是否更新支持，如果已存在，则进行更新数据
     * @param operName 操作用户
     * @return 结果
     */
    public String importRooms(List<StuRoom> stuRoomList, Boolean isUpdateSupport, String operName){
        if (StringUtils.isNull(stuRoomList) || stuRoomList.size() == 0) {
            throw new CustomException("导入数据不能为空！");
        }
        int successNum = 0;
        StringBuilder successMsg = new StringBuilder();
        StringBuilder failureMsg = new StringBuilder();
        for (StuRoom room : stuRoomList) {
            this.insertStuRoom(room);
            successNum++;
            successMsg.append("<br/>" + successNum + "、寝室号 " + room.getRoomName() + " 导入成功");
        }
        return successMsg.toString();
    }
}
