package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.ruoyi.common.utils.uuid.UUID;
import com.ruoyi.system.domain.vo.BookConfigVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StuTextBookMapper;
import com.ruoyi.system.domain.StuTextBook;
import com.ruoyi.system.service.IStuTextBookService;

/**
 * 教材Service业务层处理
 * 
 * @author liql
 * @date 2021-09-27
 */
@Service
public class StuTextBookServiceImpl implements IStuTextBookService 
{
    @Autowired
    private StuTextBookMapper stuTextBookMapper;

    /**
     * 查询教材
     * 
     * @param id 教材ID
     * @return 教材
     */
    @Override
    public StuTextBook selectStuTextBookById(String id)
    {
        return stuTextBookMapper.selectStuTextBookById(id);
    }

    /**
     * 查询教材列表
     * 
     * @param stuTextBook 教材
     * @return 教材
     */
    @Override
    public List<StuTextBook> selectStuTextBookList(StuTextBook stuTextBook)
    {
        return stuTextBookMapper.selectStuTextBookList(stuTextBook);
    }

    /**
     * 新增教材
     * 
     * @param stuTextBook 教材
     * @return 结果
     */
    @Override
    public int insertStuTextBook(StuTextBook stuTextBook)
    {
        stuTextBook.setCreateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuTextBook.setCreateBy(String.valueOf(userId));
        stuTextBook.setDelFlag(0L);
        return stuTextBookMapper.insertStuTextBook(stuTextBook);
    }

    /**
     * 修改教材
     * 
     * @param stuTextBook 教材
     * @return 结果
     */
    @Override
    public int updateStuTextBook(StuTextBook stuTextBook)
    {
        stuTextBook.setUpdateTime(DateUtils.getNowDate());
        Long userId = SecurityUtils.getLoginUser().getUser().getUserId();
        stuTextBook.setUpdateBy(String.valueOf(userId));
        return stuTextBookMapper.updateStuTextBook(stuTextBook);
    }

    /**
     * 批量删除教材
     * 
     * @param ids 需要删除的教材ID
     * @return 结果
     */
    @Override
    public int deleteStuTextBookByIds(String[] ids)
    {
        return stuTextBookMapper.deleteStuTextBookByIds(ids);
    }

    /**
     * 删除教材信息
     * 
     * @param id 教材ID
     * @return 结果
     */
    @Override
    public int deleteStuTextBookById(String id)
    {
        return stuTextBookMapper.deleteStuTextBookById(id);
    }

    /**
     * @return java.util.List<com.ruoyi.system.domain.vo.BookConfigVo>
     * @Description 教材列表
     */
    @Override
    public List<BookConfigVo> selectClassBookList() {
        return stuTextBookMapper.selectClassBookList();
    }

    /**
     * @param classId 班级id
     * @return java.util.List<com.ruoyi.system.domain.StuTextBook>
     * @Description 根据班级id查询教材
     */
    @Override
    public List<StuTextBook> selectTextBookByClassId(Long classId) {
        return stuTextBookMapper.selectTextBookByClassId(classId);
    }
}
